@@ -1,6 +1,10 @@
+# -*- coding: utf-8 -*-
+
+from __future__ import unicode_literals
+
 from django.apps import AppConfig
 
 
 class AdminPermissionsConfig(AppConfig):
     name = 'admin_permissions'
-    verbose_name = 'Admin Permissions'
\ No newline at end of file
+    verbose_name = 'Admin Permissions'
